@@ -5,7 +5,7 @@ from moodle_dl.download_service.path_tools import PathTools
 class Course:
     def __init__(self, _id: int, fullname: str, files: [File] = None):
         self.id = _id
-        self.fullname = fullname
+        self.fullname = PathTools.to_valid_name(fullname)
         if files is not None:
             self.files = files
         else:
@@ -18,7 +18,7 @@ class Course:
         message = 'Course ('
 
         message += 'id: %s' % (self.id)
-        message += ', fullname: "%s"' % (PathTools.to_valid_name(self.fullname))
+        message += ', fullname: "%s"' % (self.fullname)
         message += ', overwrite_name_with: "%s"' % (PathTools.to_valid_name(self.overwrite_name_with))
         message += ', create_directory_structure: %s' % (self.create_directory_structure)
         message += ', files: %s' % (len(self.files))
